@@ -37,6 +37,9 @@
 #                  Parameter
 #                  - detailLogging
 #                  - logFile
+# v2014-08-03 Paco Neuer Parameter IBNcanAddOPEntries mit dem eingestellt
+#                  werden kann, ob ein IBN auch OP-Punkte anlegen darf
+#                  oder nicht
 ######################################################################
 ####  Variables that should be adapted if necessary
 ####------------------------------------------------------------------
@@ -76,6 +79,7 @@ $tmpHTML = "";
 $logConstant = $iniParams["detailLogging"];
 $logFile = $iniParams["logFile"];
 $configFile = 'conf/oplist.ini';
+$IBNcanAddOPEntries = $iniParams["IBNcanAddOPEntries"];
 ######################################################################
 
 
@@ -93,7 +97,7 @@ $header = '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN">
     <body link="#0000FF" vlink="#0000FF">
     <div class="header"><img src="img/logo.jpg" width=114 height=48 border=0 alt="OPList">';
 
-$footer = '</div><div class="footer"><small>&copy; 2011 by <a href="http://software.glawar.at/oplist/" target="_blank">OPList</a> v1.8.526 (2014-07-30)</small></div></body></html>';
+$footer = '</div><div class="footer"><small>&copy; 2011 by <a href="http://software.glawar.at/oplist/" target="_blank">OPList</a> v1.9.530 (2014-08-03)</small></div></body></html>';
 
 
 session_start();
@@ -157,11 +161,22 @@ if (!isset($logFile)) {
     $logFile = 'log/oplist.log';
     file_put_contents($configFile, "; ####------------------------------------------------------------------\n", FILE_APPEND | LOCK_EX);
     file_put_contents($configFile, "; # Name der Logdatei\n", FILE_APPEND | LOCK_EX);
-    file_put_contents($configFile, "logFile = log/oplist.log\n", FILE_APPEND | LOCK_EX);
+    file_put_contents($configFile, "logFile = log/oplist.log;\n", FILE_APPEND | LOCK_EX);
 } else {
     logIntoFile("configFile hat einen Wert - naemlich <".$configFile.">");
 }
 
+if (!isset($IBNcanAddOPEntries)) {
+    logIntoFile("Wir setzen IBNcanAddOPEntries");
+    $IBNcanAddOPEntries = 0;
+    file_put_contents($configFile, "; ####------------------------------------------------------------------\n", FILE_APPEND | LOCK_EX);
+    file_put_contents($configFile, "; # 1: Gruppe IBN kann OP-Einträge anlegen\n", FILE_APPEND | LOCK_EX);
+    file_put_contents($configFile, "; # 0: Gruppe IBN kann keine OP-Einträge anlegen\n", FILE_APPEND | LOCK_EX);
+    file_put_contents($configFile, "IBNcanAddOPEntries = 0;\n", FILE_APPEND | LOCK_EX);
+} else {
+    logIntoFile("IBNcanAddOPEntries hat einen Wert - naemlich <".$IBNcanAddOPEntries.">");
+}
+
 
 #---------------------------------------------------------------------
 # (c) www.glawar.at: liefert in Abhaengigkeit der obigen Parameter in
@@ -364,7 +379,7 @@ function getEmailOfId ($userId) {
 # (c) www.glawar.at: MAIN
 #---------------------------------------------------------------------
 
-if  (isset($_POST['mode'])) {
+if (isset($_POST['mode'])) {
     $mode = $_POST['mode'];
 } elseif  (isset($_GET['mode'])) {
     $mode = $_GET['mode'];
@@ -471,9 +486,11 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
     $header .= "<a class='menuitem' title='Alle OP-Punke' href='javascript:ajx(\"list\")'><img hspace=10 src='img/list.png' width=32 height=32 border=0 alt='Alle OP-Punke'></a>";
 
 
+    if ($_SESSION['OPGID'] == "1" || $_SESSION['OPGID'] == "2" || $_SESSION['OPGID']=="4" || $IBNcanAddOPEntries == 1) {
     #if ($_SESSION['OPGID']=="1" || $_SESSION['OPGID']=="2" || $_SESSION['OPGID']=="4") {
         $header .= "<a class='menuitem' title='Neuer OP-Punkt' href='javascript:ajx(\"new\")'><img hspace=10 src='img/new.png' width=32 height=32 border=0 alt='Neuer OP-Punkt'></a>";
     #}
+    }
 
     $header .= "<a class='menuitem' title='Benutzerverwaltung' href='javascript:ajx(\"config\")'><img hspace=10 src='img/config.png' width=32 height=32 border=0 alt='Benutzerverwaltung'></a><a class='menuitem' title='Benutzerhinweise' href='javascript:ajx(\"help\");'><img hspace=10 src='img/help.png' width=32 height=32 border=0 alt='Benutzerhinweise'></a>";
 
@@ -765,7 +782,7 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
             # wir schicken den Betroffenen eine Email
             $email['FROMMAIL'] = getEmailOfId ($_SESSION['OPUID']);
             $email['SUBJECT'] = $projectName." - Neuer OP-Punkt: ".$_POST['OPENTRY'];
-            $email['MSG'] = "Der OP-Punkt\n\n".$_POST['OPENTRY']."\n\nwurde hinzugefuegt.";
+            $email['MSG'] = "Der OP-Punkt\n\n".$_POST['OPENTRY']."\n\nwurde hinzugefügt.";
             $email['HEADERS'] = "Return-path: ".$email['FROMMAIL']."\n";
             $email['HEADERS'] .= "From: <".$email['FROMMAIL'].">\n";
             $email['HEADERS'] .= "Reply-To: <".$email['FROMMAIL'].">\n";
@@ -1363,7 +1380,7 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
 
             </td>
             <td colspan=2 align=right valign=bottom>
-            <input type="submit" name="addcomment" style="width:180px;" value="Kommentar hinzufuegen" onClick="return(checkAddComment(document.addcommentform.OPCTEXT.value));">
+            <input type="submit" name="addcomment" style="width:180px;" value="Kommentar hinzufügen" onClick="return(checkAddComment(document.addcommentform.OPCTEXT.value));">
             <input type="hidden" name="OPID" value="'.$_GET['OPID'].'">
             </td>
             </tr>
@@ -1412,7 +1429,7 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
             <tr bgcolor="#f0f0f0" >
                 <td valign=top>&nbsp;<b>Bereich:</b></td>
                 <td valign=middle align=left colspan=2><select name="OPAID" style="width:200px;">
-                    <option value="-1">-- Bitte auswaehlen --';
+                    <option value="-1">-- Bitte auswählen --';
 
 
         foreach ($typeArr as $key => $val) {
@@ -1434,7 +1451,7 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
         <tr bgcolor="#f0f0f0" >
             <td valign=top>&nbsp;<b>Produkt:</b></td>
             <td valign=middle align=left colspan=2><select name="OPPID" style="width:200px;">
-                <option value="-1">-- Bitte auswaehlen --';
+                <option value="-1">-- Bitte auswählen --';
 
         foreach ($productArr as $key => $val) {
             if ($OPPID != "") {
@@ -1461,7 +1478,7 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
             $tmpHTML .= '<tr bgcolor="#f0f0f0" >
                 <td valign=middle>&nbsp;<b>Zugewiesen an:</b></td>
                 <td valign=middle align=left colspan=2><select name="OPUID_ASSIGNED" style="width:200px;">
-                <option value="">Bitte auswaehlen';
+                <option value="">Bitte auswählen';
 
             foreach ($userArr as $k => $v) {
                 if ($OPUID_ASSIGNED == $v['OPUID']) {
@@ -1502,7 +1519,7 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
                 <tr bgcolor="#f0f0f0" >
                     <td valign=top>&nbsp;<b>Priorit&auml;t</b></td>
                     <td colspan=2><select name="OPPRIO">
-                    <option value="">-- Bitte auswaehlen --';
+                    <option value="">-- Bitte auswählen --';
 
                 for ($i=0;$i<=count($prioArr)-1;$i++) {
                     if ($i == $OPPRIO ) {
@@ -1517,21 +1534,21 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
                         <td bgcolor="#ffffff" ></td>
                     </tr>';
 
-        if ($OPUID_ASSIGNED == $_SESSION['OPUID'] || $_SESSION['OPGID'] == "1" || $_SESSION['OPGID'] == "2" || $_SESSION['OPGID']=="4") {
-                if ($mode == "edit") {
-                    $tmpHTML .= '
-                            <tr >
-                                <td colspan=3 align=center><input type="hidden" name="OPID" value="'.$OPID .'"><input type="submit" name="update" style="width:180px;" value="Aenderungen speichern" onClick="return(checkOPEntry(document.opform.OPENTRY.value));"></td>
-                                <td bgcolor="#ffffff" ></td>
-                            </tr>';
-                } else {
-                    $tmpHTML .= '
+        if ($OPUID_ASSIGNED == $_SESSION['OPUID'] || $_SESSION['OPGID'] == "1" || $_SESSION['OPGID'] == "2" || $_SESSION['OPGID']=="4" || $IBNcanAddOPEntries == 1) {
+            if ($mode == "edit") {
+                $tmpHTML .= '
                     <tr >
-                        <td colspan=3 align=center><input type="submit" name="save" style="width:180px;" value="Eintrag hinzufuegen" onClick="return(checkOPEntry(document.opform.OPENTRY.value));"></td>
-                        <td bgcolor="#ffffff" ></td>
+                    <td colspan=3 align=center><input type="hidden" name="OPID" value="'.$OPID .'"><input type="submit" name="update" style="width:180px;" value="Änderungen speichern" onClick="return(checkOPEntry(document.opform.OPENTRY.value));"></td>
+                    <td bgcolor="#ffffff" ></td>
+                    </tr>';
+            } else {
+                $tmpHTML .= '
+                    <tr >
+                    <td colspan=3 align=center><input type="submit" name="save" style="width:180px;" value="Eintrag hinzufügen" onClick="return(checkOPEntry(document.opform.OPENTRY.value));"></td>
+                    <td bgcolor="#ffffff" ></td>
                     </tr>';
-                }
             }
+        }
 
 
             $tmpHTML .= '
@@ -1575,7 +1592,7 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
                 $tmpHTML .=  "<a href='" .$_SERVER['PHP_SELF'] . "?mode=edit&OPID=".$v['OPID']."'><img src='img/edit.png' hspace=2 border=0></a>";
             }
             if ($_SESSION['OPGID'] == "1") {
-                $tmpHTML .=  "<a href=\"" .$_SERVER['PHP_SELF'] . "?mode=del&OPID=".$v['OPID']."\" onClick=\"return(confirmDialogIntoFile('Wollen Sie diesen OP-Punkt wirklich loeschen?'));\"><img src='img/deletenew.png' hspace=2 border=0></a>";
+                $tmpHTML .=  "<a href=\"" .$_SERVER['PHP_SELF'] . "?mode=del&OPID=".$v['OPID']."\" onClick=\"return(confirmDialogIntoFile('Wollen Sie diesen OP-Punkt wirklich löschen?'));\"><img src='img/deletenew.png' hspace=2 border=0></a>";
             }
 
             $tmpHTML .=  "</td><td valign='top' style='font-size:10px;'>".$v['OPID']."</td>
@@ -1630,7 +1647,7 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
 
 
                         $tmpHTML .= '<tr><td class="tdh">Gruppe (*):</td><td><select name="OPGID" style="width:300px;">
-                            <option value="-1">-- Bitte auswaehlen --';
+                            <option value="-1">-- Bitte auswählen --';
 
                         foreach ($grpArr as $key => $val) {
                             if ($v['OPGID']!="") {
@@ -1655,14 +1672,14 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
                             </tr><tr><td class="tdh">Familienname (*):</td><td><input name="OPULNAME" type="text" value="'.$v['OPULNAME'] .'" style="width:200px;"></td>
                             </tr><tr><td class="tdh">Vorname (*):</td><td><input name="OPUFNAME" type="text" value="'. $v['OPUFNAME'] .'" style="width:200px;"></td>
                             </tr><tr><td class="tdh">Kennwort (*):</td><td><input name="OPUPASSWORD" type="password" value="" style="width:200px;"></td>
-                            </tr><tr><td></td><td><input type="submit" name="deleteuser" value="Loeschen"><input type="submit" name="updateuser" value="Aktualisieren" onClick="return(checkNewUser(document.pwd.OPUUSERNAME.value, document.pwd.OPGID.value, document.pwd.OPUFNAME.value, document.pwd.OPULNAME.value, document.pwd.OPUEMAIL.value, document.pwd.OPUPASSWORD.value));"><input name="OPUID" type="hidden" value="'.$v['OPUID'].'"><br><br></td></tr>';
+                            </tr><tr><td></td><td><input type="submit" name="deleteuser" value="Löschen"><input type="submit" name="updateuser" value="Aktualisieren" onClick="return(checkNewUser(document.pwd.OPUUSERNAME.value, document.pwd.OPGID.value, document.pwd.OPUFNAME.value, document.pwd.OPULNAME.value, document.pwd.OPUEMAIL.value, document.pwd.OPUPASSWORD.value));"><input name="OPUID" type="hidden" value="'.$v['OPUID'].'"><br><br></td></tr>';
                         }
                     }
                 } else {
                     $tmpHTML .= '<td width=500 valign=top><table width=100% border=0 cellpadding=3 cellspacing=2 style="border:1px solid gray;" >';
 
                     $tmpHTML .= '<tr><td class="tdh">Gruppe (*):</td><td><select name="OPGID" style="width:300px;">
-                        <option value="-1">-- Bitte auswaehlen --';
+                        <option value="-1">-- Bitte auswählen --';
 
                     foreach ($grpArr as $key => $val) {
                         $tmpHTML .= "<option value='".$val['OPGID']."'>".$val['OPGTEXT'];
